/********************************************************************************
 *
 * Copyright (c) 2007
 * Luchesar Iliev <iliev@acad.bg>
 *
 * This file is part of psping(1).
 *
 * psping is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * psping is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with psping; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 ********************************************************************************/


// HEADER GUARD
#ifndef PSPING__GARBAGE_COLLECTOR_H
#define PSPING__GARBAGE_COLLECTOR_H


/********************************************************************************
 ********************************************************************************
 **
 ** Things you should NOT change
 **
 ********************************************************************************
 ********************************************************************************/

/*
    DEFINES
*/

// Bold and normal attributes for terminal output
#define BOLD                    "\033[1m"
#define FLAT                    "\033[m"

// The maximum number of memory block pointers the garbage collector can take care of
// This should be high enough or the program might fail
#define GC_MEM_BLOCK_LENGTH     20

/*
    VARIABLES
*/

// Pointer to the memory block where the GC keeps track of its registrations
void** mem_block_list;

/*
    FUNCTIONS
*/

// Initialize the Garbage Collector register
int gc_init();

// Register a memory block
int gc_reg_mem(void*);

// Unregister a memory block
int gc_unreg_mem(void*);

// free() the registered memory blocks
void gc_free_mem();

// Deinitialize the Garbage Collector
void gc_deinit();


// HEADER GUARD
#endif                          // PSPING__GARBAGE_COLLECTOR_H

